/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { VorgangFormularButtonsE2EComponent } from 'apps/alfa-e2e/src/components/vorgang/vorgang-formular-buttons.e2e.components';
import { ConnectionTimeoutRetryDialogE2EComponent, ConnectionTimeoutRetryFailDialogE2EComponent } from '../../../components/ui/connection-timeout-retry-dialog.e2e.component';
import { VorgangDetailHeaderE2EComponent } from '../../../components/vorgang/vorgang-detail-header.e2e.component';
import { VorgangListE2EComponent } from '../../../components/vorgang/vorgang-list.e2e.component';
import { VorgangE2E } from '../../../model/vorgang';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { VorgangPage } from '../../../page-objects/vorgang.po';
import { dropCollections, interceptWithResponse, waitOfInterceptor } from '../../../support/cypress-helper';
import { contains, exist } from '../../../support/cypress.util';
import { loginAsSabine } from '../../../support/user-util';
import { createVorgang, initVorgang } from '../../../support/vorgang-util';

describe('Interceptor Connection Timeout', () => {
	const mainPage: MainPage = new MainPage();

	const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();


	const connectionTimeoutRetryDialog: ConnectionTimeoutRetryDialogE2EComponent = mainPage.getConnectionTimeoutRetryDialog();
	const connectionTimeoutRetryFailDialog: ConnectionTimeoutRetryFailDialogE2EComponent = mainPage.getConnectionTimeoutRetryFailDialog();

	const vorgangPage: VorgangPage = new VorgangPage();
	const vorgangFormularButtons: VorgangFormularButtonsE2EComponent = vorgangPage.getFormularButtons();
	const vorgangHeader: VorgangDetailHeaderE2EComponent = vorgangPage.getVorgangDetailHeader();

	const vorgang: VorgangE2E = createVorgang();

	before(() => {
		initVorgang(vorgang);

		loginAsSabine();

		waitForSpinnerToDisappear();
		exist(vorgangList.getRoot());
	})

	after(() => {
		dropCollections();
	})

	describe('annehmen', () => {

		const interceptor: string = 'doVorgangAnnehmen';
		const statusCode: number = 503;

		beforeEach(() => {
			const url: string = '*/vorgangs/602566a807bb665df9a86111/relations/602566a807bb665df9a86111/0/commands';

			interceptWithResponse('POST', url, { statusCode }).as(interceptor);
		})

		it('should navigate to vorgang detail', () => {
			vorgangList.getListItem(vorgang.name).getRoot().click();
			waitForSpinnerToDisappear();

			exist(vorgangHeader.getRoot());
		})

		it('should show retry request dialog', () => {
			vorgangFormularButtons.getAnnehmenButton().click();

			waitOfInterceptor(interceptor).then((interception) => {
				assert(interception.response.statusCode, statusCode.toString());
				exist(connectionTimeoutRetryDialog.getIcon());
				contains(connectionTimeoutRetryDialog.getHeader(), 'Es ist ein Verbindungsfehler aufgetreten ...');
				contains(connectionTimeoutRetryDialog.getMessage(), 'Ihre Anfrage wird wiederholt');
			})
		})

		it.skip('(LOCAL ONLY) should show fail dialog after time is over', () => {
			cy.wait(290000);//Hier das BE ausstellen

			exist(connectionTimeoutRetryFailDialog.getIcon());
			contains(connectionTimeoutRetryFailDialog.getHeader(), 'Zeitüberschreitung der Verbindung');
			contains(connectionTimeoutRetryFailDialog.getMessage(), 'Auch nach weiteren Versuchen konnte keine Verbindung aufgebaut werden');
			exist(connectionTimeoutRetryFailDialog.getReloadButton());
		})

		it.skip('(LOCAL ONLY) should reload page on click on button', () => {
			connectionTimeoutRetryFailDialog.getReloadButton().click();

			cy.wait(10000);//Hier das BE anstellen

			exist(vorgangPage.getVorgangDetailHeader().getRoot());
		})
	})
})