/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { VorgangE2E } from 'apps/alfa-e2e/src/model/vorgang';
import { VorgangListE2EComponent } from '../../../components/vorgang/vorgang-list.e2e.component';
import { HttpMethodE2E } from '../../../model/util';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { dropCollections, dropSearchIndex, intercept, scrollToWindowBottom, waitOfInterceptor } from '../../../support/cypress-helper';
import { enterWith, exist } from '../../../support/cypress.util';
import { generateIds } from '../../../support/tech.util';
import { loginAsSabine } from '../../../support/user-util';
import { buildVorgang, initSearchIndex, initVorgaenge } from '../../../support/vorgang-util';

describe('VorgangList: search and pagination', () => {

	const mainPage: MainPage = new MainPage();

	const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();

	const NUMBER_OF_VORGAENGE: number = 250;
	const PAGE_SIZE: number = 100;
	const vorgaenge: VorgangE2E[] = generateIds(NUMBER_OF_VORGAENGE).map((id: string, i: number) => ({ ...buildVorgang(id, `Vorgang_${i + 1}`), nummer:  `Vorgang_${i + 1}`}));

	before(() => {
		initVorgaenge(vorgaenge);
		initSearchIndex(vorgaenge);

		loginAsSabine();
	});

	after(() => {
		dropCollections();
		dropSearchIndex();
	})

	describe('open Vorgang list', () => {

		const SEARCH_BY: string = 'Vorgang';

		it('should open Vorgang list', () => {
			waitForSpinnerToDisappear();
			exist(vorgangList.getRoot());
		});

		it('should search for Vorgänge', () => {
			enterWith(mainPage.getHeader().getVorgangSearch().getInput(), SEARCH_BY);
			waitForSpinnerToDisappear();
		});

		it('should load Vorgang from second page', () => {
			const loadSecondPageIterceptor: string = 'loadSecondPage';
			intercept(HttpMethodE2E.GET, buildVorgangPageLink(2, SEARCH_BY)).as(loadSecondPageIterceptor);

			scrollToWindowBottom();

			waitOfInterceptor(loadSecondPageIterceptor).then(() => {
				exist(vorgangList.getListItem('Vorgang_110').getRoot());
			});
		})

		it('should load Vorgang from third page', () => {
			const loadThirdPageIterceptor: string = 'loadThirdPage';
			intercept(HttpMethodE2E.GET, buildVorgangPageLink(3, SEARCH_BY)).as(loadThirdPageIterceptor);

			scrollToWindowBottom();

			waitOfInterceptor(loadThirdPageIterceptor).then(() => {
				exist(vorgangList.getListItem('Vorgang_250').getRoot());
			});
		});
	});

	function buildVorgangPageLink(page: number, searchBy: string): string {
		return `*/vorgangs?page=${page - 1}&limit=${PAGE_SIZE}&searchBy=${searchBy}`;
	}
})