/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { formatDate } from '@angular/common';
import { ResourceE2E } from '../model/util';
import { getBaseUrl } from './cypress-helper';

export function formatDateLocal(date: Date | string, pattern: string): string {
	return formatDate(date, pattern, 'de');
}

export function removeLinkFromResource(obj: ResourceE2E, linkRel: string): ResourceE2E {
	delete obj._links[linkRel];
	return obj;
}

export function generateIds(toGenerate: number): string[] {
	let ids: string[] = [];

	for (let i = 0; i < toGenerate; i++) {
		let id;
		do {
			id = generate12ByteId();
			if (!ids.includes(id)) {
				ids[i] = id;
			}
		}
		while (!ids.includes(id));
	}
	return ids;
}

export function generate12ByteId(): string {
	let outString: string = '';
	let inOptions: string = 'abcdefghijklmnopqrstuvwxyz0123456789';

	for (let i = 0; i < 12; i++) {
		outString += inOptions.charAt(Math.floor(Math.random() * inOptions.length));
	}
	return outString;
}

export function buildUrl(id: string, pathPrefix: string) {
	return `${getBaseUrl()}/api/${pathPrefix}/${id}`
}

export function convertToDataTestId(value: string): string {
	if (value == null || value == undefined) {
		return null;
	}
	value = replaceAllWhitespaces(value, '_');
	return simpleTransliteration(value);
}

export function replaceAllWhitespaces(value: string, replaceWith: string): string {
	return value.replace(/ /g, replaceWith);
}

export function simpleTransliteration(value: string) {
	return value.normalize('NFKD').replace(/[^-A-Za-z0-9_]/g, '');
}

export function createDateToday(): string {
	return formatDateLocal(new Date(), 'yyyy-MM-dd');
}

export function createDateInThePast(): string {
	const today = new Date();
	today.setFullYear(today.getFullYear() - 1);
	return formatDateLocal(today, 'yyyy-MM-dd');
}

export function createDateInTheFuture(): string {
	const today = new Date();
	today.setFullYear(today.getFullYear() + 1);
	return formatDateLocal(today, 'yyyy-MM-dd');
}