import { CommandOrder, CommandResource, CreateCommand } from '@alfa-client/command-shared';
import { StateResource, createStateResource } from '@alfa-client/tech-shared';
import { Mock, mock, useFromMock } from '@alfa-client/test-utils';
import { VorgangWithEingangLinkRel, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { Store } from '@ngrx/store';
import { Resource } from '@ngxp/rest';
import { createCommandResource, createCreateCommand } from 'libs/command-shared/test/command';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { Subject } from 'rxjs';
import { BescheidFacade } from './bescheid.facade';

import * as CommandActions from '../../../../command-shared/src/lib/+state/command.actions';

describe('BescheidFacade', () => {
	const store: Mock<Store> = mock(Store);
	let facade: BescheidFacade;
	let selectSubj: Subject<StateResource<Resource>>;

	beforeEach(() => {
		selectSubj = new Subject();
		store.select.mockReturnValue(selectSubj);

		facade = new BescheidFacade(useFromMock(store));
	});

	describe('getBescheidCommand', () => {

		it('should return selected value', (done) => {
			const expected: StateResource<CommandResource> = createStateResource(createCommandResource());

			facade.getBescheidCommand().subscribe(userSettings => {
				expect(userSettings).toBe(expected);
				done();
			});

			selectSubj.next(expected);
		})
	})

	describe('createBescheid', () => {

		it('should dispatch "createCommand"', () => {
			const vorgangWithEingang: VorgangWithEingangResource = createVorgangWithEingangResource();
			const createCommand: CreateCommand = createCreateCommand(CommandOrder.CREATE_BESCHEID);

			facade.createBescheid(vorgangWithEingang, createCommand);

			expect(store.dispatch).toHaveBeenCalledWith(CommandActions.createCommand({ resource: vorgangWithEingang, linkRel: VorgangWithEingangLinkRel.CREATE_BESCHEID , command: createCommand }))
		})
	})
})