/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Component, Input, OnDestroy, OnInit } from '@angular/core';
import { HistorieFacade, HistorieListResource } from '@alfa-client/historie-shared';
import { StateResource } from '@alfa-client/tech-shared';
import { VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { Observable } from 'rxjs';

@Component({
	selector: 'alfa-historie-container',
	templateUrl: './historie-container.component.html',
	styleUrls: ['./historie-container.component.scss'],
})
export class HistorieContainerComponent implements OnInit, OnDestroy {

	@Input() vorgangWithEingang: VorgangWithEingangResource;

	historieListResource$: Observable<StateResource<HistorieListResource>>;

	constructor(private historieFacade: HistorieFacade) { }

	ngOnInit(): void {
		this.historieListResource$ = this.historieFacade.getHistorie();
	}

	ngOnDestroy(): void {
		this.historieFacade.reloadHistorie();
	}
}