import { Component, Input } from '@angular/core';
import { MatDialogRef } from '@angular/material/dialog';
import { CommandResource } from '@alfa-client/command-shared';
import { LoeschAnforderungResource, LoeschAnforderungService } from '@alfa-client/loesch-anforderung-shared';
import { StateResource, createEmptyStateResource } from '@alfa-client/tech-shared';
import { BasicDialogComponent, BasicDialogData, DialogService } from '@alfa-client/ui';
import { LoeschAnforderungLinkRel, VorgangWithEingangLinkRel, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { Observable, filter, first, of } from 'rxjs';

@Component({
	selector: 'alfa-endgueltig-loeschen-button-container',
	templateUrl: './endgueltig-loeschen-button-container.component.html',
	styleUrls: ['./endgueltig-loeschen-button-container.component.scss'],
})
export class EndgueltigLoeschenButtonContainerComponent {

	@Input() vorgang: VorgangWithEingangResource;
	@Input() showAsIconButton: boolean = false;

	commandStateResource$: Observable<StateResource<CommandResource>> = of(createEmptyStateResource<CommandResource>());
	loeschAnforderungResource$: Observable<StateResource<LoeschAnforderungResource>>;

	readonly vorgangWithEingangLinkRel = VorgangWithEingangLinkRel;
	readonly loeschAnforderungLinkRel = LoeschAnforderungLinkRel;

	dialogRef: MatDialogRef<BasicDialogComponent>;

	constructor(
		private loeschAnforderungService: LoeschAnforderungService,
		private dialogService: DialogService) {}

	ngOnInit(): void {
		this.commandStateResource$ = this.loeschAnforderungService.getEndgueltigLoeschenCommand();
		this.loeschAnforderungResource$ = this.loeschAnforderungService.getLoeschAnforderung();
	}

	public openEndgueltigLoeschenDialog(loeschAnforderungResource: StateResource<LoeschAnforderungResource>): void {
		const dialogRef: MatDialogRef<BasicDialogComponent> = this.dialogService.openBasic(this.createBasicDialogConfig());

		dialogRef.afterClosed().pipe(first(), filter(response => response === true)).subscribe(() => this.endgueltigLoeschen(loeschAnforderungResource));
	}

	createBasicDialogConfig(): BasicDialogData {
		return {
			title: 'Möchten Sie den Vorgang endgültig löschen?',
			message: 'Diese Aktion kann nicht widerrufen werden.',
			okText: 'Endgültig löschen',
			okSvgIcon: 'delete_finally'
		}
	}

	endgueltigLoeschen(loeschAnforderungResource: StateResource<LoeschAnforderungResource>): void {
		this.loeschAnforderungService.endgueltigLoeschen(loeschAnforderungResource.resource);
	}
}
