/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import faker from '@faker-js/faker';
import { PostfachMailListLinkRel } from '@alfa-client/postfach-shared';
import { EMPTY_STRING, HasLinkPipe, createStateResource } from '@alfa-client/tech-shared';
import { IconButtonWithSpinnerComponent, OzgcloudStrokedButtonWithSpinnerComponent } from '@alfa-client/ui';
import { createCommandResource } from 'libs/command-shared/test/command';
import { createPostfachMailListResource } from 'libs/postfach-shared/test/postfach';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { PostfachMailButtonComponent } from './postfach-mail-button.component';

describe('PostfachMailButtonComponent', () => {
	let component: PostfachMailButtonComponent;
	let fixture: ComponentFixture<PostfachMailButtonComponent>;

	const sendMailButtonWithText: string = getDataTestIdOf('create-mail-button-with-text');
	const sendMailButtonWithoutText: string = getDataTestIdOf('create-mail-button-without-text');
	const sendMailIconButton: string = getDataTestIdOf('send-mail-icon-button');

	beforeEach(async () => {
		await TestBed.configureTestingModule({
			declarations: [
				PostfachMailButtonComponent,
				HasLinkPipe,
				MockComponent(IconButtonWithSpinnerComponent),
				MockComponent(OzgcloudStrokedButtonWithSpinnerComponent),
			]
		})
			.compileComponents();
	});

	beforeEach(() => {
		fixture = TestBed.createComponent(PostfachMailButtonComponent);
		component = fixture.componentInstance;
		fixture.detectChanges();
	});

	it('should create', () => {
		expect(component).toBeTruthy();
	});

	describe('send mail button', () => {
		beforeEach(() => {
			component.showAsIconButton = false;
		})

		describe('with text', () => {

			beforeEach(() => {
				component.text = faker.word.noun();
				component.toolTip = EMPTY_STRING;
				fixture.detectChanges();
			})

			it('should be hidden', () => {
				component.postfachMailListStateResource = createStateResource(createPostfachMailListResource());

				fixture.detectChanges();
				const buttonElement = fixture.nativeElement.querySelector(sendMailButtonWithText);

				expect(buttonElement).not.toBeInstanceOf(HTMLElement);
			});

			it('should be visible', () => {
				component.postfachMailListStateResource = createStateResource(createPostfachMailListResource([PostfachMailListLinkRel.SEND_POSTFACH_MAIL]));
				component.pendingSendPostfachMailCommand = createStateResource(createCommandResource());

				fixture.detectChanges();
				const buttonElement = fixture.nativeElement.querySelector(sendMailButtonWithText);

				expect(buttonElement).toBeInstanceOf(HTMLElement);
			});
		})

		describe('without text', () => {

			beforeEach(() => {
				component.text = EMPTY_STRING;
				component.toolTip = faker.word.noun();
				fixture.detectChanges();
			})

			it('should be hidden', () => {
				component.postfachMailListStateResource = createStateResource(createPostfachMailListResource());

				fixture.detectChanges();
				const buttonElement = fixture.nativeElement.querySelector(sendMailButtonWithoutText);

				expect(buttonElement).not.toBeInstanceOf(HTMLElement);
			});

			it('should be visible', () => {
				component.postfachMailListStateResource = createStateResource(createPostfachMailListResource([PostfachMailListLinkRel.SEND_POSTFACH_MAIL]));
				component.pendingSendPostfachMailCommand = createStateResource(createCommandResource());

				fixture.detectChanges();
				const buttonElement = fixture.nativeElement.querySelector(sendMailButtonWithoutText);

				expect(buttonElement).toBeInstanceOf(HTMLElement);
			});
		})

	})

	describe('send mail icon button', () => {

		beforeEach(() => {
			component.showAsIconButton = true;
			fixture.detectChanges();
		})

		it('should be hidden', () => {
			component.postfachMailListStateResource = createStateResource(createPostfachMailListResource());

			fixture.detectChanges();
			const buttonElement = fixture.nativeElement.querySelector(sendMailIconButton);

			expect(buttonElement).not.toBeInstanceOf(HTMLElement);
		});

		it('should be visible', () => {
			component.postfachMailListStateResource = createStateResource(createPostfachMailListResource([PostfachMailListLinkRel.SEND_POSTFACH_MAIL]));
			component.pendingSendPostfachMailCommand = createStateResource(createCommandResource());

			fixture.detectChanges();
			const buttonElement = fixture.nativeElement.querySelector(sendMailIconButton);

			expect(buttonElement).toBeInstanceOf(HTMLElement);
		});
	})
});
