/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { PostfachService } from '@alfa-client/postfach-shared';
import { mock } from '@alfa-client/test-utils';
import { VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent } from 'ng-mocks';
import { PostfachMailListContainerComponent } from './postfach-mail-list-container.component';
import { PostfachMailListComponent } from './postfach-mail-list/postfach-mail-list.component';
import { createStateResource, StateResource } from '@alfa-client/tech-shared';

describe('PostfachMailListContainerComponent', () => {
	let component: PostfachMailListContainerComponent;
	let fixture: ComponentFixture<PostfachMailListContainerComponent>;

	const vorgangStateResource: StateResource<VorgangWithEingangResource> = createStateResource(createVorgangWithEingangResource());

	const postfachService = mock(PostfachService);

	beforeEach(async () => {
		await TestBed.configureTestingModule({
			declarations: [
				PostfachMailListContainerComponent,
				MockComponent(PostfachMailListComponent)
			],
			providers: [
				{
					provide: PostfachService,
					useValue: postfachService
				}
			]
		})
			.compileComponents();
	});

	beforeEach(() => {
		fixture = TestBed.createComponent(PostfachMailListContainerComponent);
		component = fixture.componentInstance;
		component.vorgangStateResource = vorgangStateResource;
		fixture.detectChanges();
	});

	it('should create', () => {
		expect(component).toBeTruthy();
	});

	describe('ngOnChanges', () => {

		it('should call postfach service', () => {
			component.ngOnChanges();

			expect(postfachService.getPostfachMailListByGivenVorgang).toHaveBeenCalledWith(vorgangStateResource.resource);
		})

		it('should call reloadPostfachMailListOnVorgangReload', () => {
			const reloadPostfachMailListOnVorgangReload = jest.spyOn(component, 'reloadPostfachMailListOnVorgangReload').mockReturnThis();

			component.ngOnChanges();

			expect(reloadPostfachMailListOnVorgangReload).toHaveBeenCalled();
		});
	})

	describe('reloadPostfachMailListOnVorgangReload', () => {

		beforeEach(() => {
			postfachService.setPostfachMailOnReload.mockClear();
		});

		it('should call postfachService', () => {
			component.vorgangStateResource = { ...createStateResource(createVorgangWithEingangResource()), reload: true };

			component.reloadPostfachMailListOnVorgangReload();

			expect(postfachService.setPostfachMailOnReload).toBeCalled();
		});

		it('should not call postfachService', () => {
			component.vorgangStateResource = { ...createStateResource(createVorgangWithEingangResource()), reload: false };

			component.reloadPostfachMailListOnVorgangReload();

			expect(postfachService.setPostfachMailOnReload).not.toBeCalled();
		});

	});
});
