/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Component, Input, OnChanges } from '@angular/core';
import { ON_PAGE, PostfachMailListResource, PostfachService } from '@alfa-client/postfach-shared';
import { isNotNull, StateResource } from '@alfa-client/tech-shared';
import { VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { Observable } from 'rxjs';

@Component({
	selector: 'alfa-postfach-mail-list-container',
	templateUrl: './postfach-mail-list-container.component.html',
	styleUrls: ['./postfach-mail-list-container.component.scss'],
	providers: [{ provide: ON_PAGE, useValue: false }]
})
export class PostfachMailListContainerComponent implements OnChanges {

	@Input() vorgangStateResource: StateResource<VorgangWithEingangResource>;

	postfachMailListStateResource$: Observable<StateResource<PostfachMailListResource>>;

	constructor(private postfachService: PostfachService) { }

	ngOnChanges() {
		if (isNotNull(this.vorgangStateResource)) {
			this.reloadPostfachMailListOnVorgangReload();
			this.postfachMailListStateResource$ = this.postfachService.getPostfachMailListByGivenVorgang(this.vorgangStateResource.resource);
		}
	}

	reloadPostfachMailListOnVorgangReload(): void {
		if (this.vorgangStateResource.reload) {
			this.postfachService.setPostfachMailOnReload();
		}
	}
}
