import { Component, Input } from '@angular/core';
import { PostfachMailFormDialogData, PostfachMailResource } from '@alfa-client/postfach-shared';
import { EMPTY_STRING, StateResource, isNotNil } from '@alfa-client/tech-shared';
import { DialogService } from '@alfa-client/ui';
import { Antragsteller, VorgangWithEingang } from '@alfa-client/vorgang-shared';
import { PostfachMailFormComponent } from 'libs/postfach/src/lib/postfach-mail-form/postfach-mail-form.component';

@Component({
	selector: 'alfa-postfach-nachricht-edit-button-container',
	templateUrl: './postfach-nachricht-edit-button-container.component.html',
	styleUrls: ['./postfach-nachricht-edit-button-container.component.scss'],
})
export class PostfachNachrichtEditButtonContainerComponent {

	@Input() postfachNachricht: PostfachMailResource;
	@Input() vorgangStateResource: StateResource<VorgangWithEingang>;

	constructor(private dialogService: DialogService) { }

	public edit(): void {
		this.dialogService.openFixed(this.buildDialogData());
	}

	buildDialogData(): PostfachMailFormDialogData {
		return {
			title: 'Nachricht bearbeiten',
			component: PostfachMailFormComponent,
			postfachNachricht: this.postfachNachricht,
			empfaenger: this.getEmpfaenger()
		}
	}

	getEmpfaenger(): string {
		return `${this.getVorname()} ${this.getNachname()}`.trim();
	}

	private getVorname(): string {
		return isNotNil(this.getAntragsteller()?.vorname) ? this.getAntragsteller().vorname : EMPTY_STRING;
	}

	private getNachname(): string {
		return isNotNil(this.getAntragsteller()?.nachname) ? this.getAntragsteller().nachname : EMPTY_STRING;
	}

	private getAntragsteller(): Antragsteller {
		return this.vorgangStateResource.resource.eingang.antragsteller;
	}
}