/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CatchHttpError } from '@alfa-client/tech-shared';
import { Mock, mock, useFromMock } from '@alfa-client/test-utils';
import { HttpErrorHandler } from '../error/error.handler';
import { catchHttpErrorHandleErrorResponse, handleDefaultErrorHandling, handleDefaultRetryHandling } from './catch-http-error.decorator';

describe('CatchHttpError Decorator', () => {

	let httpErrorHandler: Mock<HttpErrorHandler>;

	beforeEach(() => {
		httpErrorHandler = mock(HttpErrorHandler);
	})

	it('should be created', () => {
		expect(CatchHttpError).toBeTruthy();
	})

	describe('handleDefaultErrorHandling', () => {

		it('should call http error handler if is true', () => {
			handleDefaultErrorHandling(true, useFromMock(httpErrorHandler));

			expect(httpErrorHandler.disableDefaultHandling).toHaveBeenCalled();
		})

		it('should do nothing if is false', () => {
			handleDefaultErrorHandling(false, useFromMock(httpErrorHandler));

			expect(httpErrorHandler.disableDefaultHandling).not.toHaveBeenCalled();
		})
	})

	describe('handleDefaultRetryHandling', () => {

		it('should call http error handler if is true', () => {
			handleDefaultRetryHandling(true, useFromMock(httpErrorHandler));

			expect(httpErrorHandler.disableRetry).toHaveBeenCalled();
		})

		it('should do nothing if is false', () => {
			handleDefaultRetryHandling(false, useFromMock(httpErrorHandler));

			expect(httpErrorHandler.disableRetry).not.toHaveBeenCalled();
		})
	})

	describe('catchHttpErrorCatchError', () => {

		const response = {};
		const name: string = 'registeredMethodName';

		it('should enable default error handling', () => {
			catchHttpErrorHandleErrorResponse(useFromMock(httpErrorHandler), response, name);

			expect(httpErrorHandler.enableDefaultHandling).toHaveBeenCalled();
		})

		it('should enable default retry handling', () => {
			catchHttpErrorHandleErrorResponse(useFromMock(httpErrorHandler), response, name);

			expect(httpErrorHandler.enableRetry).toHaveBeenCalled();
		})

		it('should execute post error method from http error handler', () => {
			catchHttpErrorHandleErrorResponse(useFromMock(httpErrorHandler), response, name);

			expect(httpErrorHandler.doAfterErrorReceived).toHaveBeenCalledWith(name, response);
		})
	})
})