import { ComponentFixture, TestBed } from '@angular/core/testing';
import { NoopAnimationsModule } from '@angular/platform-browser/animations';
import { ApiRootLinkRel } from '@alfa-client/api-root-shared';
import { GetUrlPipe, HasLinkPipe, createEmptyStateResource, createStateResource } from '@alfa-client/tech-shared';
import { getElementFromDomRoot } from '@alfa-client/test-utils';
import { MenuItemComponent, OzgcloudIconComponent, UiModule } from '@alfa-client/ui';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { createApiRootResource } from '../../../../../libs/api-root-shared/test/api-root';
import { DocumentationComponent } from './documentation/documentation.component';
import { HelpMenuComponent } from './help-menu.component';

describe('HelpMenuComponent', () => {
	let component: HelpMenuComponent;
	let fixture: ComponentFixture<HelpMenuComponent>;

	const helpMenuButton: string = getDataTestIdOf('help-menu-button');
	const documentationsComponent: string = getDataTestIdOf('documentations-component');

	beforeEach(async () => {
		await TestBed.configureTestingModule({
			declarations: [
				HelpMenuComponent,
				HasLinkPipe,
				GetUrlPipe,
				MockComponent(MenuItemComponent),
				MockComponent(DocumentationComponent),
				MockComponent(OzgcloudIconComponent),
				MockComponent(DocumentationComponent)
			],
			imports: [
				UiModule,
				NoopAnimationsModule,
			]
		}).compileComponents();

		fixture = TestBed.createComponent(HelpMenuComponent);
		component = fixture.componentInstance;
		component.apiRootStateResource = createStateResource(createApiRootResource());
		fixture.detectChanges();
	});

	it('should create', () => {
		expect(component).toBeTruthy();
	});

	describe('help menu button', () => {

		it('should be hidden', () => {
			const item = getElementFromDomRoot(fixture, helpMenuButton);

			expect(item).not.toBeInstanceOf(HTMLElement);
		});

		it('should be shown', () => {
			component.apiRootStateResource = createStateResource(createApiRootResource([ApiRootLinkRel.DOCUMENTATIONS]));

			fixture.detectChanges();

			const item = getElementFromDomRoot(fixture, helpMenuButton);
			expect(item).toBeInstanceOf(HTMLElement);
		});
	});

	describe('getNumberOfMenuItems', () => {

		it('should return 1', () => {
			component.apiRootStateResource = createStateResource(createApiRootResource([ApiRootLinkRel.DOCUMENTATIONS]));

			const result = component.getNumberOfMenuItems();

			expect(result).toEqual(1);
		});

		it('should return 0 if state resource is null', () => {
			component.apiRootStateResource = null;

			const result = component.getNumberOfMenuItems();

			expect(result).toEqual(0);
		});

		it('should return 0 if resource is null', () => {
			component.apiRootStateResource = createEmptyStateResource();

			const result = component.getNumberOfMenuItems();

			expect(result).toEqual(0);
		});
	});
});
