/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { createEmptyStateResource, createStateResource, StateResource } from '@alfa-client/tech-shared';
import { mock, Mock, useFromMock } from '@alfa-client/test-utils';
import { UserProfileResource, UserProfileService } from '@alfa-client/user-profile-shared';
import { cold, hot } from 'jest-marbles';
import { createUserProfileResource } from 'libs/user-profile-shared/test/user-profile';
import { createUserSettings, createUserSettingsResource } from 'libs/user-settings-shared/test/user-settings';
import { Observable } from 'rxjs';
import { UserSettingsFacade } from './+state/user-settings.facade';
import { UserSettings, UserSettingsResource } from './user-settings.model';
import { UserSettingsService } from './user-settings.service';

describe('UserSettingsService', () => {
	let facade: Mock<UserSettingsFacade>;
	let userProfileService: Mock<UserProfileService>;

	let service: UserSettingsService;

	beforeEach(() => {
		facade = mock(UserSettingsFacade);
		userProfileService = mock(UserProfileService);

		service = new UserSettingsService(useFromMock(facade), useFromMock(userProfileService));
	});

	it('should be created', () => {
		expect(service).toBeTruthy();
	});

	describe('get user settings', () => {
		const userProfileResource: UserProfileResource = createUserProfileResource();
		const stateResourceCU = createStateResource(createUserSettingsResource());
		const emptyStateResourceCU = createEmptyStateResource<UserProfileResource>(true);

		beforeEach(() => {
			const stateResourceUP: StateResource<UserProfileResource> = createStateResource(userProfileResource);
			userProfileService.getCurrentUser.mockReturnValue(hot('a', { a: stateResourceUP }));

			facade.getUserSettings.mockReturnValue(hot('-a', { a: stateResourceCU }));
		})

		it('should call userProfileService.getCurrentUser', () => {
			service.getUserSettings();

			expect(userProfileService.getCurrentUser).toHaveBeenCalled();
		})

		it.skip('should load user settings from facade', (done) => {
			service.getUserSettings().subscribe(() => {
				expect(facade.loadUserSettings).toHaveBeenCalledWith(userProfileResource);
				done();
			});
		})

		it('should return user settings', () => {
			const userSettings$: Observable<StateResource<UserSettingsResource>> = service.getUserSettings();

			expect(userSettings$).toBeObservable(cold('ab', { a: emptyStateResourceCU, b: stateResourceCU }));
		})

	})

	describe('set UserSettings', () => {
		it('should call set method in facade', () => {
			const userSettings: UserSettings = createUserSettings();

			service.setUserSettings(userSettings);

			expect(facade.setUserSettings).toHaveBeenCalledWith(userSettings);
		})
	})
});
