import { ComponentFixture, TestBed } from '@angular/core/testing';
import { CommandResource } from '@alfa-client/command-shared';
import { StateResource, createEmptyStateResource, createStateResource } from '@alfa-client/tech-shared';
import { dispatchEventFromFixture, getMockComponent, mock } from '@alfa-client/test-utils';
import { OzgcloudButtonWithSpinnerComponent } from '@alfa-client/ui';
import { VorgangService, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { createCommandResource } from 'libs/command-shared/test/command';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { ProcessVorgangContainerComponent } from './vorgang-process-vorgang-container.component';

describe('ProcessVorgangContainerComponent', () => {
	let component: ProcessVorgangContainerComponent;
	let fixture: ComponentFixture<ProcessVorgangContainerComponent>;

	const commandStateResource: StateResource<CommandResource> = createStateResource(createCommandResource());
	const vorgangWithEingang: VorgangWithEingangResource = createVorgangWithEingangResource();
	const vorgangService = mock(VorgangService);

	const button: string = '[dataTestId="process-vorgang"]';

	beforeEach(async () => {
		await TestBed.configureTestingModule({
			declarations: [
				ProcessVorgangContainerComponent,
				MockComponent(OzgcloudButtonWithSpinnerComponent)
			],
			providers: [
				{
					provide: VorgangService,
					useValue: vorgangService
				}
			]
		}).compileComponents();

		fixture = TestBed.createComponent(ProcessVorgangContainerComponent);
		component = fixture.componentInstance;
		component.vorgangWithEingang = vorgangWithEingang;
		vorgangService.processVorgang.mockReturnValue(of(commandStateResource));
		fixture.detectChanges();
	});

	it('should create', () => {
		expect(component).toBeTruthy();
	});

	describe('handleCommand', () => {

		it('should closeMenu if processing is done', () => {
			jest.spyOn(component.closeMenu, 'emit');

			component.handleCommand(createStateResource(createCommandResource()));

			expect(component.closeMenu.emit).toHaveBeenCalled();
		})
	})

	describe('processVorgang', () => {

		it('should call service processVorgang', () => {
			dispatchEventFromFixture(fixture, button, 'clickEmitter');

			expect(vorgangService.processVorgang).toHaveBeenCalledWith(vorgangWithEingang);
		})
	})

	describe('button component should be called with', () => {

		it('stateResource', () => {
			const button: OzgcloudButtonWithSpinnerComponent = getMockComponent(fixture, OzgcloudButtonWithSpinnerComponent);

			expect(button.stateResource).toEqual(createEmptyStateResource());
		})

		it('text', () => {
			const button: OzgcloudButtonWithSpinnerComponent = getMockComponent(fixture, OzgcloudButtonWithSpinnerComponent);

			expect(button.text).toBe('Vorgang vorprüfen');
		})

		it('icon', () => {
			const button: OzgcloudButtonWithSpinnerComponent = getMockComponent(fixture, OzgcloudButtonWithSpinnerComponent);

			expect(button.svgIcon).toBe('done');
		})
	})
})