/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CommandOrder, CreateCommand } from '@alfa-client/command-shared';
import { createVorgangForwardRequest, createVorgangListResource } from 'libs/vorgang-shared/test/vorgang';
import { VorgangListLinkRel } from './vorgang.linkrel';
import { ForwardRequest, VorgangResource } from './vorgang.model';
import { createAbschliessenCommand, createAnnehmenCommand, createAssignUserCommand, createBearbeitenCommand, createBescheidenCommand, createForwardCommand, createProcessVorgangCommand, createVerwerfenCommand, createZurueckholenCommand, createZurueckstellenCommand, getVorgaengeFromList } from './vorgang.util';

import faker from '@faker-js/faker';

describe('VorgangUtil', () => {

	describe('create ZurueckholenCommand', () => {

		it('should return command', () => {
			const command: CreateCommand = createZurueckholenCommand();

			expect(command.order).toBe(CommandOrder.VORGANG_ZURUECKHOLEN);
		})
	})

	describe('create AnnehmenCommand', () => {

		it('should return command', () => {
			const command: CreateCommand = createAnnehmenCommand();

			expect(command.order).toBe(CommandOrder.VORGANG_ANNEHMEN);
		})
	})

	describe('create VerwerfenCommand', () => {

		it('should return command', () => {
			const command: CreateCommand = createVerwerfenCommand();

			expect(command.order).toBe(CommandOrder.VORGANG_VERWERFEN);
		})
	})

	describe('create BearbeitenCommand', () => {

		it('should return command', () => {
			const command: CreateCommand = createBearbeitenCommand();

			expect(command.order).toBe(CommandOrder.VORGANG_BEARBEITEN);
		})
	})

	describe('create BescheidenCommand', () => {

		it('should return command', () => {
			const command: CreateCommand = createBescheidenCommand();

			expect(command.order).toBe(CommandOrder.VORGANG_BESCHEIDEN);
		})
	})

	describe('create ZurückstellenCommand', () => {

		it('should return command', () => {
			const command: CreateCommand = createZurueckstellenCommand();

			expect(command.order).toBe(CommandOrder.VORGANG_ZURUECKSTELLEN);
		})
	})

	describe('create AbschliessenCommand', () => {

		it('should return command', () => {
			const command: CreateCommand = createAbschliessenCommand();

			expect(command.order).toBe(CommandOrder.VORGANG_ABSCHLIESSEN);
		})
	})

	describe('create ForwardCommand', () => {

		it('should return command', () => {
			const forwardRequest: ForwardRequest = createVorgangForwardRequest();

			const result: CreateCommand = createForwardCommand(forwardRequest);

			expect(result).toEqual({ order: CommandOrder.REDIRECT_VORGANG, redirectRequest: forwardRequest, body: null })
		})
	})

	describe('getVorgaengeFromList', () => {

		it('should return empty array on null', () => {
			const result: VorgangResource[] = getVorgaengeFromList(null);

			expect(result.length).toBe(0);
		})

		it('should return content as array', () => {
			const result: VorgangResource[] = getVorgaengeFromList(createVorgangListResource([VorgangListLinkRel.VORGANG_HEADER_LIST]));

			expect(result.length).toBe(10);
		})
	})

	describe('create createAssignUserCommand', () => {

		const userProfileUri: string = faker.internet.url();

		it('should return command', () => {
			const result: CreateCommand = createAssignUserCommand(userProfileUri);

			expect(result).toEqual({ order: CommandOrder.ASSIGN_USER, body: { assignedTo: userProfileUri } })
		})
	})

	describe('create createProcessVorgangCommand', () => {

		it('should have order',  () => {
			const command: CreateCommand = createProcessVorgangCommand([]);

			expect(command.order).toBe(CommandOrder.PROCESS_VORGANG);
		})

		it('should have processorNames',  () => {
			const processorNames: string[] = ['dummyProcessorName'];

			const command: CreateCommand = createProcessVorgangCommand(processorNames);

			expect(command.body.processorNames).toBe(processorNames);
		})
	})
})