/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { faker } from '@faker-js/faker';
import { mock, useFromMock } from '@alfa-client/test-utils';
import { VorgangHeaderLinkRel, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { ResourceFactory, ResourceUri } from '@ngxp/rest';
import { cold, hot } from 'jest-marbles';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { createWiedervorlageListResource, createWiedervorlageResource } from '../../test/wiedervorlage';
import { WiedervorlageListResource, WiedervorlageResource } from './wiedervorlage.model';
import { WiedervorlageRepository } from './wiedervorlage.repository';

describe('WiedervorlageRepository', () => {
	let repository: WiedervorlageRepository;
	let resourceFactory = mock(ResourceFactory);
	let resourceWrapper = { get: jest.fn() };

	beforeEach(() => {
		repository = new WiedervorlageRepository(useFromMock(resourceFactory));
	})

	describe('loadWiedervorlagenList', () => {
		const wiedervorlageListResource: WiedervorlageListResource = createWiedervorlageListResource();
		const vorgangResource: VorgangWithEingangResource = createVorgangWithEingangResource();

		beforeEach(() => {
			resourceFactory.from.mockReturnValue(resourceWrapper);
			resourceWrapper.get.mockReturnValue(cold('a', { a: wiedervorlageListResource }));
		})

		it('should call resourceFactory with resource', () => {
			repository.getWiedervorlageList(vorgangResource);

			expect(resourceFactory.from).toHaveBeenCalledWith(vorgangResource);
		})

		it('should call resourceWrapper with link', () => {
			repository.getWiedervorlageList(vorgangResource);

			expect(resourceWrapper.get).toHaveBeenCalledWith(VorgangHeaderLinkRel.WIEDERVORLAGEN);
		})

		it('should return result', () => {
			let result = repository.getWiedervorlageList(vorgangResource);

			expect(result).not.toBeNull();
			expect(result).toBeObservable(hot('a', { a: wiedervorlageListResource }));
		})
	})

	describe('getWiedervorlage', () => {
		const wiedervorlageUri: ResourceUri = faker.internet.url();
		const wiedervorlageResource: WiedervorlageResource = createWiedervorlageResource();

		beforeEach(() => {
			resourceFactory.fromId.mockReturnValue(resourceWrapper);
			resourceWrapper.get.mockReturnValue(cold('a', { a: wiedervorlageResource }));
		})

		it('should call resourceFactory with resource', () => {
			repository.getWiedervorlage(wiedervorlageUri);

			expect(resourceFactory.fromId).toHaveBeenCalledWith(wiedervorlageUri);
		})

		it('should call resourceWrapper with link', () => {
			repository.getWiedervorlage(wiedervorlageUri);

			expect(resourceWrapper.get).toHaveBeenCalled();
		})

		it('should return result', () => {
			let result = repository.getWiedervorlage(wiedervorlageUri);

			expect(result).not.toBeNull();
			expect(result).toBeObservable(hot('a', { a: wiedervorlageResource }));
		})
	})
})