/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.common.clientattribute;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import de.ozgcloud.vorgang.grpc.clientAttribute.GrpcClientAttribute;
import de.ozgcloud.vorgang.grpc.clientAttribute.GrpcClientAttributeValue;
import de.ozgcloud.vorgang.grpc.clientAttribute.GrpcUpdateClientAttributeRequest;

@Service
public class ClientAttributeService {

	public static final String HAS_NEW_POSTFACH_NACHRICHT_ATTRIBUTE_NAME = "hasNewPostfachNachricht";
	static final String ORIGINAL_CLIENT_NAME = "OzgCloud_NachrichtenManager";

	@Autowired
	private ClientAttributeRemoteService remoteService;

	public void resetPostfachNachricht(String vorgangId) {
		remoteService.resetPostfachNachricht(buildResetNewPostfachNachricht(vorgangId));
	}

	GrpcUpdateClientAttributeRequest buildResetNewPostfachNachricht(String vorgangId) {
		return buildRequest(vorgangId, false, HAS_NEW_POSTFACH_NACHRICHT_ATTRIBUTE_NAME);
	}

	private GrpcUpdateClientAttributeRequest buildRequest(String vorgangId, boolean value, String attributeName) {
		return GrpcUpdateClientAttributeRequest.newBuilder()
				.setVorgangId(vorgangId)
				.setAttribute(
						GrpcClientAttribute.newBuilder().setValue(
										GrpcClientAttributeValue.newBuilder().setBoolValue(value).build())
								.setClientName(ORIGINAL_CLIENT_NAME)
								.setAttributeName(attributeName)
								.build())
				.build();
	}

}
