package de.ozgcloud.alfa.loeschanforderung;

import static org.springframework.hateoas.server.mvc.WebMvcLinkBuilder.*;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.hateoas.EntityModel;
import org.springframework.hateoas.LinkRelation;
import org.springframework.hateoas.server.RepresentationModelAssembler;
import org.springframework.stereotype.Component;

import de.ozgcloud.alfa.common.ModelBuilder;

@Component
class LoeschAnforderungModelAssembler implements RepresentationModelAssembler<LoeschAnforderung, EntityModel<LoeschAnforderung>> {

	static final LinkRelation REL_EXECUTE_LOESCHEN = LinkRelation.of("execute_loeschen");
	static final LinkRelation REL_LOESCH_ANFORDERUNG_ZURUECKNEHMEN = LinkRelation.of("zuruecknehmen");

	@Autowired
	private LoeschAnforderungService loeschAnforderungService;

	@Override
	public EntityModel<LoeschAnforderung> toModel(LoeschAnforderung loeschAnforderung) {
		return ModelBuilder.fromEntity(loeschAnforderung)
				.addLink(linkTo(methodOn(LoeschAnforderungController.class).getLoeschanforderung(loeschAnforderung.getId())).withSelfRel())
				.ifMatch(loeschAnforderungService::isAllowedToVorgangLoeschen)
				.addLink(linkTo(methodOn(LoeschAnforderungCommandController.class).createCommand(loeschAnforderung.getId(), null)).withRel(
						REL_EXECUTE_LOESCHEN))
				.addLink(linkTo(methodOn(LoeschAnforderungCommandController.class).createCommand(loeschAnforderung.getId(), null)).withRel(
						REL_LOESCH_ANFORDERUNG_ZURUECKNEHMEN))
				.buildModel();
	}
}
