/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.vorgang;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import de.ozgcloud.alfa.common.GrpcUtil;
import de.ozgcloud.vorgang.vorgang.GrpcFilterBy;
import de.ozgcloud.vorgang.vorgang.GrpcFindVorgangRequest;
import de.ozgcloud.vorgang.vorgang.GrpcFindVorgangRequest.GrpcOrderBy;
import de.ozgcloud.vorgang.vorgang.GrpcFindVorgangResponse;
import de.ozgcloud.vorgang.vorgang.GrpcFindVorgangWithEingangRequest;
import de.ozgcloud.vorgang.vorgang.GrpcFindVorgangWithEingangResponse;
import de.ozgcloud.vorgang.vorgang.VorgangServiceGrpc.VorgangServiceBlockingStub;
import net.devh.boot.grpc.client.inject.GrpcClient;

@Service
class VorgangRemoteService {

	@GrpcClient(GrpcUtil.VORGANG_MANAGER_GRPC_CLIENT)
	private VorgangServiceBlockingStub vorgangServiceStub;
	@Autowired
	private VorgangHeaderMapper vorgangHeaderMapper;
	@Autowired
	private VorgangWithEingangMapper vorgangWithEingangMapper;

	public VorgaengeHeaderResponse findVorgaengeHeader(FindVorgaengeHeaderRequestCriteria requestCriteria, FilterCriteria filterCriteria) {
		var request = buildFindVorgangRequest(requestCriteria, filterCriteria);

		var response = vorgangServiceStub.findVorgang(request);

		return buildVorgaengeHeaderResponse(response);
	}

	GrpcFindVorgangRequest buildFindVorgangRequest(FindVorgaengeHeaderRequestCriteria requestCriteria, FilterCriteria filterCriteria) {
		var requestBuilder = createFindVorgangRequestBuilder(requestCriteria, filterCriteria);

		requestCriteria.getSearchBy().ifPresent(requestBuilder::setSearchBy);

		return requestBuilder.build();
	}

	private GrpcFindVorgangRequest.Builder createFindVorgangRequestBuilder(FindVorgaengeHeaderRequestCriteria requestCriteria,
			FilterCriteria filterCriteria) {
		return GrpcFindVorgangRequest.newBuilder()
				.setOrderBy(GrpcOrderBy.valueOf(requestCriteria.getOrderBy().name()))
				.setLimit(requestCriteria.getLimit())
				.setOffset(requestCriteria.getPage() * requestCriteria.getLimit())
				.setFilterBy(mapFilterCriteria(filterCriteria));
	}

	VorgaengeHeaderResponse buildVorgaengeHeaderResponse(GrpcFindVorgangResponse response) {
		return VorgaengeHeaderResponse.builder().total(response.getTotal()).vorgaengeHeader(getVorgaengeHeaderFromResponse(response)).build();
	}

	private List<VorgangHeader> getVorgaengeHeaderFromResponse(GrpcFindVorgangResponse response) {
		return response.getVorgangList().stream().map(vorgangHeaderMapper::toVorgangHeader).toList();
	}

	public VorgangWithEingang findVorgangWithEingang(String vorgangId, FilterCriteria filterCriteria) {
		var request = buildFindVorgangWithEingangRequest(vorgangId, filterCriteria);

		var response = vorgangServiceStub.findVorgangWithEingang(request);

		return buildVorgangWithEingangResponse(response);
	}

	GrpcFindVorgangWithEingangRequest buildFindVorgangWithEingangRequest(String vorgangId, FilterCriteria filterCriteria) {
		return GrpcFindVorgangWithEingangRequest.newBuilder().setId(vorgangId).setFilterBy(mapFilterCriteria(filterCriteria)).build();
	}

	GrpcFilterBy mapFilterCriteria(FilterCriteria filterCriteria) {
		var filterCriteriaBuilder = GrpcFilterBy.newBuilder()
				.setFilterByAssignedTo(filterCriteria.isFilterByAssignedTo())
				.setFilterByOrganisationseinheitenId(filterCriteria.isFilterByOrganisationseinheitenId())
				.addAllOrganisationseinheitId(filterCriteria.getOrganisationsEinheitenId())
				.setHasNextWiedervorlageFrist(filterCriteria.isHasNextWiedervorlageFrist());

		filterCriteria.getAssignedTo().ifPresent(assignedTo -> filterCriteriaBuilder.setAssignedTo(assignedTo.toString()));
		filterCriteria.getStatus().ifPresent(status -> filterCriteriaBuilder.addStatus(status.toString()));

		return filterCriteriaBuilder.build();
	}

	private VorgangWithEingang buildVorgangWithEingangResponse(GrpcFindVorgangWithEingangResponse response) {
		return vorgangWithEingangMapper.toVorgangWithEingang(response.getVorgangWithEingang());
	}
}