/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.historie;

import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.*;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.*;

import java.util.List;
import java.util.stream.Stream;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.mock.mockito.MockBean;
import org.springframework.security.test.context.support.WithMockUser;
import org.springframework.test.web.servlet.MockMvc;

import de.ozgcloud.alfa.common.attacheditem.VorgangAttachedItemService;
import de.ozgcloud.alfa.common.command.Command;
import de.ozgcloud.alfa.common.command.CommandOrder;
import de.ozgcloud.alfa.common.command.CommandService;
import de.ozgcloud.alfa.common.command.CommandTestFactory;
import de.ozgcloud.alfa.vorgang.VorgangHeaderTestFactory;

@WithMockUser
@AutoConfigureMockMvc
@SpringBootTest
class HistorieControllerITCase {
	private final String PATH = HistorieController.PATH + "?vorgangId=";

	@MockBean
	private CommandService service;
	@MockBean
	private VorgangAttachedItemService vorgangAttachedItemService;

	@Autowired
	private MockMvc mockMvc;

	@DisplayName("Get all")
	@WithMockUser
	@Nested
	class TestGetAll {

		@BeforeEach
		void init() {
			when(vorgangAttachedItemService.findLoeschAnforderung(any())).thenReturn(Stream.empty());
			when(service.findFinishedCommands(any())).thenReturn(createCommandStream());
		}

		private Stream<Command> createCommandStream() {
			return List.of(CommandTestFactory.create()).stream();
		}

		@Test
		void shouldReturnStatusOk() throws Exception {
			mockMvc.perform(get(PATH + VorgangHeaderTestFactory.ID)).andExpect(status().isOk());
		}

		@Test
		void shouldContainCommands() throws Exception {
			var response = mockMvc.perform(get(PATH + VorgangHeaderTestFactory.ID)).andExpect(status().isOk());

			response.andExpect(jsonPath("$._embedded.commandList[0].order").value(CommandOrder.VORGANG_ANNEHMEN.name()))
					.andExpect(jsonPath("$._embedded.commandList[0]").isNotEmpty());

		}
	}

}
