package de.ozgcloud.alfa.system;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

class SystemStatusServiceTest {

	@InjectMocks
	private SystemStatusService service;

	@Mock
	private SystemStatusRemoteService remoteService;

	@Nested
	class TestIsSearchServerAvailable {

		@BeforeEach
		void mockService() {
			when(remoteService.getSystemStatus()).thenReturn(PlutoSystemStatusTestFactory.create());
		}

		@Test
		void shouldCallRemoteService() {
			service.isSearchServerAvailable();

			verify(remoteService).getSystemStatus();
		}

		@Test
		void shouldRemotAvailablity() {
			var result = service.isSearchServerAvailable();

			assertThat(result).isEqualTo(PlutoSystemStatusTestFactory.SEARCH_AVAILABLE);
		}

		@Test
		void shouldReturnFalseOnError() {
			when(remoteService.getSystemStatus()).thenThrow(RuntimeException.class);
			
			var result = service.isSearchServerAvailable();
			
			assertThat(result).isFalse();
		}
	}
}
