/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.wiedervorlage;

import java.time.LocalDate;
import java.time.ZonedDateTime;
import java.util.Map;
import java.util.UUID;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.alfa.common.binaryfile.BinaryFileTestFactory;
import de.ozgcloud.alfa.vorgang.VorgangHeaderTestFactory;

public class WiedervorlageTestFactory {

	public static final String ID = UUID.randomUUID().toString();
	public static final long VERSION = 73;
	public static final boolean DONE = false;
	public static final String CREATED_BY = UUID.randomUUID().toString();
	public static final String CREATED_BY_NAME = LoremIpsum.getInstance().getName();

	public static final String BETREFF = "Lorem Ipsum";
	public static final String BESCHREIBUNG = "Lorem Ipsum dolores est";
	public static final String FRIST_STR = "2121-01-04";
	public static final LocalDate FRIST = LocalDate.parse(FRIST_STR);
	public static final String CREATED_AT_STR = "2021-01-10T10:30:00Z";
	public static final ZonedDateTime CREATED_AT = ZonedDateTime.parse(CREATED_AT_STR);

	public static Wiedervorlage create() {
		return createBuilder().build();
	}

	public static Wiedervorlage.WiedervorlageBuilder createBuilder() {
		return Wiedervorlage.builder()
				.id(ID)
				.version(VERSION)
				.done(DONE)
				.betreff(BETREFF)
				.beschreibung(BESCHREIBUNG)
				.createdBy(CREATED_BY)
				.createdAt(CREATED_AT)
				.frist(FRIST)
				.vorgangId(VorgangHeaderTestFactory.ID)
				.attachment(BinaryFileTestFactory.FILE_ID);
	}

	public static Map<String, Object> createAsMap() {
		return Map.of(
				WiedervorlageMapper.ID, ID,
				WiedervorlageMapper.DONE, String.valueOf(DONE),
				WiedervorlageMapper.CREATED_BY, CREATED_BY,
				WiedervorlageMapper.CREATED_BY_NAME, CREATED_BY_NAME,
				WiedervorlageMapper.BETREFF, BETREFF,
				WiedervorlageMapper.BESCHREIBUNG, BESCHREIBUNG,
				WiedervorlageMapper.FRIST, FRIST_STR,
				WiedervorlageMapper.CREATED_AT, CREATED_AT_STR,
				WiedervorlageMapper.ATTACHMENTS, BinaryFileTestFactory.ID);
	}
}