package de.ozgcloud.alfa.export;

import java.util.Optional;
import java.util.function.Predicate;

import javax.xml.datatype.XMLGregorianCalendar;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import de.ozgcloud.alfa.vorgang.Antragsteller;
import de.ozgcloud.alfa.vorgang.VorgangWithEingang;
import de.xoev.xdomea.GeburtType;
import de.xoev.xdomea.KontaktType;

@Component
class KontaktTypeCreator {

	private final Predicate<Antragsteller> HAS_VORNAME = antragsteller -> StringUtils.isNotBlank(antragsteller.getVorname());
	private final Predicate<Antragsteller> HAS_NACHNAME = antragsteller -> StringUtils.isNotBlank(antragsteller.getNachname());
	private final Predicate<Antragsteller> HAS_ANREDE = antragsteller -> StringUtils.isNotBlank(antragsteller.getAnrede());
	private final Predicate<Antragsteller> HAS_VALID_GEBURTSDATUM = this::hasValidGeburtsdatum;

	@Autowired
	private NameNatuerlichePersonTypeCreator nameNatuerlichePersonTypeCreator;

	@Autowired
	private DateConverter dateConverter;

	public Optional<KontaktType> create(VorgangWithEingang vorgang) {
		return getAntragstellerIfHasRequiredData(vorgang).map(this::toKontaktType);
	}

	Optional<Antragsteller> getAntragstellerIfHasRequiredData(VorgangWithEingang vorgang) {
		return Optional.ofNullable(vorgang.getEingang().getAntragsteller())
				.filter(HAS_VORNAME.or(HAS_NACHNAME).or(HAS_ANREDE).or(HAS_VALID_GEBURTSDATUM));
	}

	KontaktType toKontaktType(Antragsteller antragsteller) {
		var kontakt = new KontaktType();
		kontakt.setName(nameNatuerlichePersonTypeCreator.create(antragsteller));
		var geburtsdatumIso = dateConverter.convertGermanFormatToISO(antragsteller.getGeburtsdatum());
		kontakt.setGeburt(createGeburtType(geburtsdatumIso));
		return kontakt;
	}

	GeburtType createGeburtType(Optional<XMLGregorianCalendar> geburtsdatum) {
		return geburtsdatum.map(this::createGeburtType).orElseGet(GeburtType::new);
	}

	private GeburtType createGeburtType(XMLGregorianCalendar datum) {
		var geburtType = new GeburtType();
		geburtType.setDatum(datum);
		return geburtType;
	}

	private boolean hasValidGeburtsdatum(Antragsteller antragsteller) {
		return dateConverter.convertGermanFormatToISO(antragsteller.getGeburtsdatum()).isPresent();
	}

}
