package de.ozgcloud.alfa.export;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.alfa.vorgang.VorgangWithEingang;
import de.ozgcloud.alfa.vorgang.VorgangWithEingangTestFactory;
import de.xoev.xdomea.AbgabeAbgabe0401.Schriftgutobjekt;
import de.xoev.xdomea.AnwendungsspezifischeErweiterungType;

class AbgabeAbgabe0401CreatorTest {

	@InjectMocks
	private AbgabeAbgabe0401Creator creator;

	@Mock
	private SchriftgutobjektCreator schriftgutobjektCreator;

	@Mock
	private AnwendungsspezifischeErweiterungTypeCreator anwendungsspezifischeErweiterungTypeCreator;

	@Nested
	class TestCreate {

		private final VorgangWithEingang vorgangWithEingang = VorgangWithEingangTestFactory.create();

		private final AnwendungsspezifischeErweiterungType anwendungsspezifischeErweiterung = AnwendungsspezifischeErweiterungTypeTestFactory.create();
		private final Schriftgutobjekt schriftgutobjekt = SchriftgutobjektTestFactory.create();

		@BeforeEach
		void init() {
			when(anwendungsspezifischeErweiterungTypeCreator.create(vorgangWithEingang)).thenReturn(
					anwendungsspezifischeErweiterung);
		}

		@Test
		void shouldCallMapper() {
			creator.create(vorgangWithEingang);

			verify(anwendungsspezifischeErweiterungTypeCreator).create(vorgangWithEingang);
		}

		@Test
		void shouldCreateSchriftgutobjekt() {
			creator.create(vorgangWithEingang);

			verify(schriftgutobjektCreator).create(vorgangWithEingang, anwendungsspezifischeErweiterung);
		}

		@Test
		void shouldHaveSchriftgutobjekt() {
			doReturn(schriftgutobjekt).when(schriftgutobjektCreator).create(vorgangWithEingang, anwendungsspezifischeErweiterung);

			var abgabe = creator.create(vorgangWithEingang);

			assertThat(abgabe.getSchriftgutobjekt().get(0)).isEqualTo(schriftgutobjekt);
		}
	}

}