package de.ozgcloud.alfa.export;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.alfa.common.TestUtils;
import de.ozgcloud.alfa.common.file.OzgFile;
import de.ozgcloud.alfa.common.file.OzgFileTestFactory;

class ExportFilenameGeneratorTest {

	@InjectMocks
	private ExportFilenameGenerator generator;

	@Mock
	private UUIDConverter uuidConverter;

	@Nested
	class TestGenerateExportFilename {

		private static final String UUID = "64a820d3-6285-172a-c028-0000000026d0";

		private final OzgFile ozgFile = OzgFileTestFactory.create();

		@BeforeEach
		void init() {
			when(uuidConverter.fromObjectId(ozgFile.getId().toString())).thenReturn(UUID);
		}

		@Test
		void shouldConvertObjectId() {
			callGenerator();

			verify(uuidConverter).fromObjectId(ozgFile.getId().toString());
		}

		@Test
		void shouldGenerate() {
			var filename = callGenerator();

			assertThat(filename).matches(String.format("^%s_%s$", TestUtils.UUID_REGEX, ozgFile.getName()));
		}

		private String callGenerator() {
			return generator.generateExportFilename(ozgFile);
		}
	}

}